#include <math.h>
#include <grass/gis.h>

#define PI	M_PI
#define Radians(x) ((x) * PI/180.0)
#define Degrees(x) ((x) * 180.0/PI)
